WSDSLSpecOptions = ['RSpec', 'Bacon'] # usually pulled from a model

describe_service "services/test" do |service|
  service.formats  :xml, :json
  service.http_verb :get

  service.params do |p|
    p.string :framework, :in => WSDSLSpecOptions, :null => false, :required => true

    p.datetime :timestamp, :default => Time.now
    p.string   :alpha,     :in      => ['a', 'b', 'c']
    p.string   :version,   :null    => false
    p.integer  :num,      :minvalue => 42, :maxvalue => 1000
    p.string   :name,  :minlength => 5, :maxlength => 25

  end

  # service.param :delta, :optional => true, :type => 'float'
  # # if the optional flag isn't passed, the param is considered required.
  # service.param :epsilon, :type => 'string'

  service.params.namespace :user do |user|
    user.integer :id, :required => :true
    user.string :sex, :in => %Q{female, male}
    user.boolean :mailing_list, :default => true
    user.array :groups, :required => true, :in => %w{developer admin manager}
    user.array :skills, :in => %w{ruby java networking}
  end

  # the response contains a list of player creation ratings each object in the list

  service.response do |response|
    response.element(:name => "player_creation_ratings") do |e|
      e.attribute  :id          => :integer, :doc => "id doc"
      e.attribute  :is_accepted => :boolean, :doc => "is accepted doc"
      e.attribute  :name        => :string,  :doc => "name doc"

      e.array :name => 'player_creation_rating', :type => 'PlayerCreationRating' do |a|
        a.attribute :comments  => :string,  :doc => "comments doc"
        a.attribute :player_id => :integer, :doc => "player_id doc"
        a.attribute :rating    => :integer, :doc => "rating doc"
        a.attribute :username  => :string,  :doc => "username doc"
      end
    end
  end

  service.documentation do |doc|
    # doc.overall <markdown description text>
    doc.overall <<-DOC
     This is a test service used to test the framework.
    DOC

    # doc.params <name>, <definition>
    doc.param :framework, "The test framework used, could be one of the two following: #{WSDSLSpecOptions.join(", ")}."
    doc.param :version, "The version of the framework to use."

    # doc.example <markdown text>
    doc.example <<-DOC
The most common way to use this service looks like that:
    http://example.com/services/test.xml?framework=rspec&version=2.0.0
    DOC
  end
end


describe_service "services/test_no_params" do |service|
  service.formats  :xml
  service.http_verb :get
  service.accept_no_params!
end

describe_service "services" do |service|
  service.formats  :xml
  service.http_verb :put

end

describe_service "services/array_param" do |s|
  s.formats :xml
  s.http_verb :post

  s.params do |p|
    p.array :seq, :required => true
  end

end
